@@ -27,6 +27,7 @@ from random import randint
 from .WXBizMsgCrypt import WXBizMsgCrypt, SHA1
 from .helper import QywxXMLParser, QywxResponseGeneral
 from karuo.helpers.char_helper import ensureString
+from deprecated.sphinx import deprecated
 
 def _refreshAccessToken(corpid: str, corpsecret: str):
     """
@@ -295,13 +296,14 @@ class QywxClient(_QywxBase):
         _, ret_encrypt_xml = wxcpt.EncryptMsg(replyMsg, nonce)
         return ret_encrypt_xml
 
-    def OauthRedirectUrl(self, url: str, state: str) -> str:
+    def OauthRedirectUrl(self, url: str, state: str, baseinfo: bool=True) -> str:
         """
         构造oauth认证跳转地址
         """
+        snsapi_lvl = "snsapi_base" if baseinfo else "snsapi_privateinfo"
         ret_url = ""
         if url and state:
-            ret_url = f"https://open.weixin.qq.com/connect/oauth2/authorize?appid={self._corpid}&redirect_uri={urllib.parse.quote(url)}&response_type=code&scope=snsapi_base&state={state}#wechat_redirect"
+            ret_url = f"https://open.weixin.qq.com/connect/oauth2/authorize?appid={self._corpid}&redirect_uri={urllib.parse.quote(url)}&response_type=code&scope={snsapi_lvl}&state={state}#wechat_redirect"
         return ret_url
 
     def SsoQrcodeRedirectUrl(self, agendid: str, url: str, state: str) -> str:
@@ -335,9 +337,11 @@ class QywxClient(_QywxBase):
         else:
             return False, None
 
+    @deprecated(version="0.7", reason="企业微信接口调整")
     def UserList(self, department_id: int, fetch_child: int = 0, detail: bool = False):
         """
         获取部门成员列表
+        @deprecated
         :param department_id:
         :param fetch_child: 1: 递归全部， 0: 当前层级
         :param detail: 是否获取完整的用户信息，默认否
@@ -350,7 +354,7 @@ class QywxClient(_QywxBase):
         url = "https://qyapi.weixin.qq.com/cgi-bin/user/list" if detail else "https://qyapi.weixin.qq.com/cgi-bin/user/simplelist"
         return self.getRequest(url, _params)
         
-
+    @deprecated(version="0.7", reason="企业微信接口调整")
     def UserDetail(self, userid: str):
         """
         获取用户的详细信息
@@ -363,6 +367,49 @@ class QywxClient(_QywxBase):
         return self.getRequest(
             "https://qyapi.weixin.qq.com/cgi-bin/user/get", _params)
 
+    def UserIdListBatch(self, limit: int, cursor: str = None):
+        """
+        分批获取成员ID列表
+        """
+        _params = {
+            "limit": limit,
+            "cursor": cursor
+        }
+        return self.postRequest(
+            "https://qyapi.weixin.qq.com/cgi-bin/user/list_id", _params
+        )
+
+    def UserIdListFull(self, batch_size: int = 100):
+        """
+        全量获取
+        """
+        user_list = []
+        errorcode = 0
+        errmsg = "ok"
+        _cursor_code = None
+        _res, _data = self.UserIdListBatch(batch_size, _cursor_code)
+        if _res:
+            _cursor_code = _data.get("next_cursor", None)
+            user_list.extend(_data.get("dept_user", []))
+            while _cursor_code:
+                _res, _data = self.UserIdListBatch(batch_size, _cursor_code)
+                if _res:
+                    _cursor_code = _data.get("next_cursor", None)
+                    user_list.extend(_data.get("dept_user", []))
+                else:
+                    errorcode = _data.get("errcode", -1)
+                    errmsg = _data.get("errmsg", "")
+                    break
+        else:
+            errorcode = _data.get("errcode", -1)
+            errmsg = _data.get("errmsg", "")
+
+        return self._checkReponse({
+            "errcode": errorcode,
+            "errmsg": errmsg,
+            "dept_user": user_list
+        })
+
     def UserCreate(self, userid: str, name: str, alias:str, mobile: str, email:str, gender: int, position: str = "", telephone: str = "", department: list = [], is_leader: list = [], invite=False):
         """
         创建企业成员
@@ -428,6 +475,7 @@ class QywxClient(_QywxBase):
         return self.getRequest(
             "https://qyapi.weixin.qq.com/cgi-bin/user/delete", params)
 
+    @deprecated(version="0.7", reason="企业微信接口调整")
     def DepartmentList(self, pid: int = 1):
         """
         获取部门列表
@@ -440,6 +488,16 @@ class QywxClient(_QywxBase):
         return self.getRequest(
             "https://qyapi.weixin.qq.com/cgi-bin/department/list", _params)
         
+    def DepartmentSimpleList(self, parent_dep_id: int = None):
+        """
+        获取子部门ID列表
+        """
+        _params = {
+            "id": parent_dep_id,
+        }
+        return self.getRequest(
+            "https://qyapi.weixin.qq.com/cgi-bin/department/simplelist", _params
+        )
 
     def DepartmentCreate(self, name, parentid: int = 1, order: int = 0):
         """
