@@ -334,6 +334,21 @@ class ProxySuiteUnit:
         """
         return f"https://open.weixin.qq.com/connect/oauth2/authorize?appid={self._suite_id}&redirect_uri={quote(redirect_url)}&response_type=code&scope={scope}&state={state}#wechat_redirect"
 
+    def SetSessionInfo4Auth(self, pre_auth_code: str, auth_type: int = 0):
+        """
+        针对某次授权进行配置，支持测试环境
+        :param pre_auth_code str 安装应用的预授权码
+        :param auth_type int 授权类型： 0正式授权 1测试授权
+        """
+        _req_url = f"https://qyapi.weixin.qq.com/cgi-bin/service/set_session_info?suite_access_token={self.getSuiteAccessToken()}"
+        return self.postRequest(_req_url, {
+            "pre_auth_code":pre_auth_code,
+            "session_info":
+            {
+                "auth_type": auth_type
+            }
+        })
+
     def _refreshSuiteAccessToken(self):
         """
         获取开发套件的访问凭据
@@ -379,6 +394,29 @@ class ProxySuiteUnit:
             }
         return None
 
+    def _refreshCorpAccessToken(self, corp_id: str, pernament_code: str):
+        """
+        获取第三方服务授权企业的access token
+        """
+        _req_url = f"https://qyapi.weixin.qq.com/cgi-bin/service/get_corp_token?suite_access_token={self.getSuiteAccessToken()}"
+        _ret, _req_result = self.postRequest(_req_url, {
+            "auth_corpid": corp_id,
+ 	        "permanent_code": pernament_code
+        })
+        if _ret:
+            _access_token = _req_result.get("access_token")
+            _expires_in = _req_result.get("expires_in")
+            # 设置过期时间，使其提前5分钟过期
+            _exp_timestamp = int(
+                time.time()) + (_expires_in - 300 if _expires_in > 300 else _expires_in)
+            return {
+                "exptm": _exp_timestamp,
+                "corp_access_token": _access_token
+            }
+        else:
+            logger.error(_req_result)
+        return None
+
     def getAccessToken(self) -> str:
         """
         获取待开发授权应用的access_token
@@ -409,6 +447,36 @@ class ProxySuiteUnit:
                     pickle.dump(_refresh_data, wf)
         return ret_token
 
+    def getCorpAccessToken(self, corp_id: str, pernament_code: str) -> str:
+        """
+        获取授权企业的access token
+        """
+        ret_token = None
+        ret_expiretm = 0
+        _tmppath = tempfile.gettempdir()
+        if not os.path.isdir(_tmppath):
+            raise Exception("template path is invalid")
+        _cache_token_file = os.path.join(_tmppath, f"corp_access_token_{self._corp_id}.bin")
+        if os.path.isfile(_cache_token_file):
+            with open(_cache_token_file, "rb") as f:
+                logger.debug("load access_token from cache file")
+                _catched_data = pickle.load(f)
+                logger.debug(_catched_data)
+                if isinstance(_catched_data, dict) and "exptm" in _catched_data and _catched_data.get("exptm") > int(time.time()):
+                    ret_token = _catched_data.get("corp_access_token", "")
+                    ret_expiretm = _catched_data.get("exptm")
+        if not ret_token or ret_expiretm < int(time.time()):
+            # 没有从缓存文件中成功加载token，重新刷新token
+            _refresh_data = self._refreshCorpAccessToken(corp_id, pernament_code)
+            logger.debug("get corp_access_token from cache file")
+            logger.debug(_refresh_data)
+            if isinstance(_refresh_data, dict):
+                ret_token = _refresh_data.get("corp_access_token")
+                # 将刷新后的token写入缓存文件
+                with open(_cache_token_file, "wb") as wf:
+                    pickle.dump(_refresh_data, wf)
+        return ret_token
+
     def getSuiteAccessToken(self) -> str:
         """
         获取开发套件的访问凭据（启用本地缓存机制）
@@ -617,6 +685,15 @@ class ProxySuiteUnit:
         _url = f"https://qyapi.weixin.qq.com/cgi-bin/service/auth/getuserinfo3rd?suite_access_token={self.getSuiteAccessToken()}&code={code}"
         return self.getRequest(_url, {})
 
+    def getUserDetailInfor3rd(self, user_ticket: str):
+        """
+        获取访问用户敏感信息
+        """
+        _url = f"https://qyapi.weixin.qq.com/cgi-bin/service/auth/getuserdetail3rd?suite_access_token={self.getSuiteAccessToken()}"
+        return self.postRequest(_url, {
+            "user_ticket": user_ticket
+        })
+
     def UserIdListBatch(self, batchsize: int = 100):
         """
         批量获取用户编号
